@@ -65,7 +65,7 @@ func init() {
 	entCmd.Flags().Bool("file-only", false, "Only output the file path of matches")
 	entCmd.Flags().BoolP("diff", "d", false, "Diff entitlements")
 	entCmd.Flags().BoolP("md", "m", false, "Markdown style output")
-	entCmd.Flags().Bool("ui", false, "Show entitlements UI")
+	entCmd.Flags().Bool("ui", false, "Show entitlements Web UI")
 	entCmd.Flags().String("ui-host", "localhost", "UI host to server on")
 	entCmd.Flags().Int("ui-port", 3993, "UI port to server on")
 	viper.BindPFlag("ent.ipsw", entCmd.Flags().Lookup("ipsw"))
@@ -78,10 +78,9 @@ func init() {
 	viper.BindPFlag("ent.diff", entCmd.Flags().Lookup("diff"))
 	viper.BindPFlag("ent.md", entCmd.Flags().Lookup("md"))
 	viper.BindPFlag("ent.ui", entCmd.Flags().Lookup("ui"))
-	viper.BindPFlag("ent.ui-host", entCmd.Flags().Lookup("ui"))
-	viper.BindPFlag("ent.ui-port", entCmd.Flags().Lookup("ui"))
+	viper.BindPFlag("ent.ui-host", entCmd.Flags().Lookup("ui-host"))
+	viper.BindPFlag("ent.ui-port", entCmd.Flags().Lookup("ui-port"))
 	entCmd.MarkFlagsMutuallyExclusive("key", "val", "ui")
-	entCmd.Flags().MarkHidden("ui")
 }
 
 // entCmd represents the ent command
@@ -209,8 +208,8 @@ var entCmd = &cobra.Command{
 			}
 			return ent.UI(db, &ent.Config{
 				Version: version,
-				Host:    viper.GetString("ent.host"),
-				Port:    viper.GetInt("ent.port"),
+				Host:    viper.GetString("ent.ui-host"),
+				Port:    viper.GetInt("ent.ui-port"),
 			})
 		} else if doDiff { // DIFF ENTITLEMENTS
 			if len(searchFile) > 0 { // DIFF MACHO'S ENTITLEMENTS
